==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyTableClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyTableClass

// class file dependencies
// @dep_class 79d842c31f08f6ea gnu_xml_xpath_XPathParser__24YyTableClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct {
	_jc_short_array	*yyTable;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyTableClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyTableClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods	gnu_xml_xpath_XPathParser__24YyTableClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs	gnu_xml_xpath_XPathParser__24YyTableClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyTableClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyTableClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyTableClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyTableClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyTableClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyTableClass

// class file dependencies
// @dep_class 79d842c31f08f6ea gnu_xml_xpath_XPathParser__24YyTableClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct {
	_jc_short_array	*yyTable;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyTableClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyTableClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyTableClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vmethods	gnu_xml_xpath_XPathParser__24YyTableClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_refs	gnu_xml_xpath_XPathParser__24YyTableClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyTableClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyTableClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyTableClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyTableClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyTableClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyTableClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyTableClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyTableClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyTableClass_H_ */
